# JumpSeat Travel Module

Module adds JumpSeat Travel and Aircraft Transfer capabilities to phpVMS v7 for your pilots/users. Frontends are widgets which can be placed anywhere you wish.  
There are no settings for the module itself, no database tables are there either. All settings/adjustments are done via widget config arrays.

## Installation Steps

* Manual Install : Upload contents of the package to your root/modules folder via ftp or your control panel's file manager
* GitHub Clone : Clone/pull repository to your root/modules/JumpSeat folder
* PhpVms Module Installer : Go to admin -> addons/modules , click Add New , select downloaded file and click Add Module

Go to admin section and enable the module, that's all.  
After enabling/disabling or updating modules application cache cleaning process may be necessary (check admin/maintenance).

## Usage

Place the widgets to anywhere protected with login/auth.  
Dashboard or User Profile or any other password protected area will be ok 'cause widgets will not be visible without login

### JumpSeat Travel

` @widget('JumpSeat::JumpSeat') `  

Adjust the options if you wish for JumpSeat Travel.

* `['price' => 'free']` (this is the default option) no ticket costs, travel is free of charge.
* `['price' => 50]` (or any number you wish except 0) ticket will cost 50 $/Eur (currency comes from your phpvms settings).
* `['price' => 'auto']` ticket price will be calculated according to the great circle distance between airports travelled.

* `['base' => 0.25]` force the auto price system to use 0.25 cents per nautical mile.
* `['list' => 'hubs']` lists only your hubs as possible destinations
* `['dest' => $flight->dpt_airport_id]` removes the airport selection dropdown and displays travel button for the airport specified

` @widget('JumpSeat::JumpSeat', ['price' => 'auto', 'base' => 0.20]) `

Please be carefull with the base price definition, anything above 0.50 will make your jumpseats really expensive 'cause it gets multiplied by the distance directly.

Real world companies normally offer reduced/discounted prices to "ID Travel" partners (other company workers), though they are mostly lower than their base economy ticket prices and offer services between economy and business class, 0.13 or 0.15 cents per nm are good start/default values to have.

Fixed destination can be any airport id (4 letter ICAO Designator) you wish, like a hub ($hub->id) or a flight's departure airport as shown above

### Aircraft Transfer

` @widget('JumpSeat::TransferAircraft') `  

Adjust the options if you wish for Aircraft Transfer.

* `['price' => 'free']` (this is the default option) no costs, aircraft transfer is free of charge.
* `['price' => 'auto']` transfer fee will be calculated according to the great circle distance between airports.
* `['price' => 25000]` transfer will cost 25,000 (currency comes from your phpvms settings).

* `['list' => 'hub']` lists only aircraft parked at its own hub
* `['list' => 'hubs']` lists aircraft parked at any hub
* `['list' => 'nohubs']` lists aircraft parked at non hub airports

* `['aircraft' => $aircraft->id]` removes the aircraft selection dropdown and displays travel button for the aircraft specified

* `['landing' => 24]` lists aircraft landed "before" given *hours* (including aircraft not flown before)

` @widget('JumpSeat::JumpSeat', ['price' => 'auto', 'list' => 'hub']) `

Auto price calculation uses great circle distance and average fuel burn per nautical miles of the subfleet which the aircraft belongs to. Also it considers both arrival and departure ground handling fees (with subfleet multiplier applied).

Aircraft selection dropdown will only show fleet members which the user is allowed to fly (Settings; Aircraft restrictions by Rank), Active, Parked and which are not located at user's current location.

Fixed aircraft selection can be used if you have a specific page for displaying your fleet and/or its members (like Disposable Airlines module's Aircraft Details of Fleet pages). "Transfer" button will trigger the process for that aircraft.

"landing" option can be used as a safety feature, to block recently landed aircraft being transferred before a given time period. Like "user a" flies with "aircraft 1" and then "user b" transfers that aircraft to somewhere else just after landing, while "user a" is preparing for the return flight etc.

## Duplicating Module Blades/Views

Technically all blade files should work with your template but they are mainly designed for Bootstrap compatible themes. So if something looks weird in your template then you need to edit them. I kindly suggest copying them under your theme folder and do your changes there, directly editing module files will only make updating harder for you.

All Disposable Modules are capable of displaying customized files located under your theme folders;

* Original Location : `root/modules/DisposableModule/Resources/Views/somefile.blade.php`
* Target Location   : `root/resources/views/layouts/YourTheme/modules/DisposableModule/somefile.blade.php`

## Thanks

Thanks to Nabeel and Andreas for their support during the development of this module.

## Update Notes

18.OCT.21
* Performance improvements

11.SEP.21
* PT-BR Translation (Thanks to Edson Felix)

03.SEP.21
* Added Aircraft Transfer Widget
* Cleaned up some code

18.JUN.21
* Added a new option for fixed destination

20.APR.21
* Added a new option to only list hubs as selectable destinations
