<?php

namespace Modules\JumpSeat\Widgets;

use App\Contracts\Widget;
use App\Models\Aircraft;
use App\Models\Airport;
use App\Models\Enums\AircraftState;
use App\Models\Enums\AircraftStatus;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Auth;


class TransferAircraft extends Widget
{
  protected $config = ['aircraft' => null, 'list' => null, 'landing' => null, 'price' => 'free'];

  public function run()
  {
    $action = '\Modules\JumpSeat\Http\Controllers\JumpSeatController@actransfer';
    $price = $this->config['price'];
    $selected_ac = $this->config['aircraft'];

    if ($price != 'free' && $price != 'auto' && !is_numeric($price)) {
      $price = 'free';
    }

    $user = Auth::user();
    $dest = isset($user->curr_airport_id) ? $user->curr_airport_id : $user->home_airport_id;

    $hubs = Airport::where('hub', 1)->pluck('id')->toArray();

    // Get Aircraft which are NOT at User's location, Parked and Active
    $aircraft = Aircraft::with('subfleet.airline')
      ->where('airport_id', '!=', $dest)
      ->where(['state' => AircraftState::PARKED, 'status' => AircraftStatus::ACTIVE])
      ->orderBy('icao')->orderby('registration')
      ->get();

    // PHPVMS Settings Check
    if (setting('pireps.restrict_aircraft_to_rank')) {
      $allowed_subfleets = $user->rank->subfleets->pluck('id')->toArray();
      $aircraft = $aircraft->whereIn('subfleet_id', $allowed_subfleets);
    }

    // Aircraft Check
    if (is_numeric($selected_ac)) {
      $aircraft = $aircraft->where('id', $selected_ac);
    }

    // List Check
    if ($this->config['list'] === 'hub') {
      $aircraft = $aircraft->whereIn('airport_id', $hubs);
      $aircraft = $aircraft->filter(function ($ac) { return $ac->airport_id === $ac->subfleet->hub_id; });
    }

    elseif ($this->config['list'] === 'hubs') {
      $aircraft = $aircraft->whereIn('airport_id', $hubs);
    }

    elseif ($this->config['list'] === 'nohubs') {
      $aircraft = $aircraft->whereNotIn('airport_id', $hubs);
    }

    // Landing Time Check
    if (is_numeric($this->config['landing'])) {
      $before = Carbon::now()->subHours($this->config['landing']);
      $aircraft_notused = $aircraft->whereNull('landing_time');
      $aircraft = $aircraft->where('landing_time', '<', $before)->merge($aircraft_notused);
    }

    return view('JumpSeat::transfer_aircraft', [
      'action'      => $action,
      'aircraft'    => $aircraft,
      'price'       => $price,
      'dest'        => $dest,
      'selected_ac' => $selected_ac,
    ]);
  }
}
